@@ -6,7 +6,6 @@
 ;; Homepage: https://github.com/emacsorphanage/htmlize
 ;; Keywords: hypermedia, extensions
 ;; Package-Version: 1.59
-;; Package-Revision: release/1.59-0-ga24ed5a939a3
 ;; Package-Requires: ((emacs "26.1"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -1206,7 +1205,7 @@ If no rgb.txt file is found, return nil."
          (def (cond ((stringp raw-def) (list :foreground raw-def))
                     ((listp raw-def) raw-def)
                     (t
-                     (error "Face override must be %s, got %s"
+                     (error "Face override must be %s, got %S"
                             "an attribute list or string" raw-def)))))
     (and def
          (htmlize-attrlist-to-fstruct def (symbol-name face)))))
